==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Classes/structllarp_1_1net_1_1ipv6__header.md <==
---
title: llarp::net::ipv6_header

---

# llarp::net::ipv6_header





## Public Functions

|                | Name           |
| -------------- | -------------- |
| [llarp::nuint32_t](Classes/structllarp_1_1nuint__t.md) | **[FlowLabel](Classes/structllarp_1_1net_1_1ipv6__header.md#function-flowlabel)**() const |
| void | **[FlowLabel](Classes/structllarp_1_1net_1_1ipv6__header.md#function-flowlabel)**([llarp::nuint32_t](Classes/structllarp_1_1nuint__t.md) label)<br>put 20 bit truncated flow label network order  |

## Public Attributes

|                | Name           |
| -------------- | -------------- |
| [ipv6_header_preamble_le](Classes/structllarp_1_1net_1_1ipv6__header__preamble__le.md)< oxenc::little_endian > | **[preamble](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-preamble)**  |
| uint32_t | **[flowlabel](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-flowlabel)**  |
| union llarp::net::ipv6_header::@0 | **[preamble](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-preamble)**  |
| uint16_t | **[payload_len](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-payload-len)**  |
| uint8_t | **[proto](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-proto)**  |
| uint8_t | **[hoplimit](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-hoplimit)**  |
| in6_addr | **[srcaddr](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-srcaddr)**  |
| in6_addr | **[dstaddr](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-dstaddr)**  |

## Public Functions Documentation

### function FlowLabel

```cpp
llarp::nuint32_t FlowLabel() const
```


### function FlowLabel

```cpp
void FlowLabel(
    llarp::nuint32_t label
)
```

put 20 bit truncated flow label network order 

## Public Attributes Documentation

### variable preamble

```cpp
ipv6_header_preamble_le< oxenc::little_endian > preamble;
```


### variable flowlabel

```cpp
uint32_t flowlabel;
```


### variable preamble

```cpp
union llarp::net::ipv6_header::@0 preamble;
```


### variable payload_len

```cpp
uint16_t payload_len;
```


### variable proto

```cpp
uint8_t proto;
```


### variable hoplimit

```cpp
uint8_t hoplimit;
```


### variable srcaddr

```cpp
in6_addr srcaddr;
```


### variable dstaddr

```cpp
in6_addr dstaddr;
```


-------------------------------

Updated on 2022-05-31 at 02:25:19 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Classes/structllarp_1_1net_1_1ipv6__header.md <==
---
title: llarp::net::ipv6_header

---

# llarp::net::ipv6_header





## Public Functions

|                | Name           |
| -------------- | -------------- |
| llarp::nuint32_t | **[FlowLabel](Classes/structllarp_1_1net_1_1ipv6__header.md#function-flowlabel)**() const |
| void | **[FlowLabel](Classes/structllarp_1_1net_1_1ipv6__header.md#function-flowlabel)**(llarp::nuint32_t label)<br>put 20 bit truncated flow label network order  |

## Public Attributes

|                | Name           |
| -------------- | -------------- |
| ipv6_header_preamble | **[preamble](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-preamble)**  |
| uint32_t | **[flowlabel](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-flowlabel)**  |
| union llarp::net::ipv6_header::@0 | **[preamble](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-preamble)**  |
| uint16_t | **[payload_len](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-payload-len)**  |
| uint8_t | **[protocol](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-protocol)**  |
| uint8_t | **[hoplimit](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-hoplimit)**  |
| in6_addr | **[srcaddr](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-srcaddr)**  |
| in6_addr | **[dstaddr](Classes/structllarp_1_1net_1_1ipv6__header.md#variable-dstaddr)**  |

## Public Functions Documentation

### function FlowLabel

```cpp
llarp::nuint32_t FlowLabel() const
```


### function FlowLabel

```cpp
void FlowLabel(
    llarp::nuint32_t label
)
```

put 20 bit truncated flow label network order 

## Public Attributes Documentation

### variable preamble

```cpp
ipv6_header_preamble preamble;
```


### variable flowlabel

```cpp
uint32_t flowlabel;
```


### variable preamble

```cpp
union llarp::net::ipv6_header::@0 preamble;
```


### variable payload_len

```cpp
uint16_t payload_len;
```


### variable protocol

```cpp
uint8_t protocol;
```


### variable hoplimit

```cpp
uint8_t hoplimit;
```


### variable srcaddr

```cpp
in6_addr srcaddr;
```


### variable dstaddr

```cpp
in6_addr dstaddr;
```


-------------------------------

Updated on 2022-11-29 at 18:11:26 +0000
